@@ -224,6 +224,17 @@ class ToolbarTitle(Gtk.Bin):
         self.__signal_id = self.__entry.connect("changed",
                                                 self.__on_entry_changed)
 
+    def add_dot_com(self):
+        """
+            Add dot com to URI
+        """
+        bounds = self.__entry.get_selection_bounds()
+        if bounds:
+            current = self.__entry.get_text()[:bounds[0]]
+        else:
+            current = self.__entry.get_text()
+        self.set_text_entry(current + ".com")
+
     def set_uri(self, uri):
         """
             Update internal uri
